
# Command line interface

```{program-output} python -m demesdraw -h
```

## demes tubes

```{program-output} python -m demesdraw tubes -h
```

## demes size_history

```{program-output} python -m demesdraw size_history -h
